@@ -1,9 +1,13 @@
 from thegraph_handlers._exceptions import SubgraphError
+from thegraph_handlers.dodoex_v2 import DodoexV2
 from thegraph_handlers.sushiswap import Sushiswap
 from thegraph_handlers.uniswap_v2 import UniswapV2
+from thegraph_handlers.uniswap_v3 import UniswapV3
 
 __all__ = (
     "UniswapV2",
+    "UniswapV3",
     "SubgraphError",
     "Sushiswap",
+    "DodoexV2",
 )
