@@ -12,8 +12,6 @@ class AbstractHandler(abc.ABC):
     def __init__(
         self,
         client: AClosableHTTPClient,
-        url: str,
-        parser_dispatch: ParserDispatch,
     ) -> None:
         pass
 
