@@ -10,19 +10,15 @@ from thegraph_handlers.sushiswap.parsers import (
 
 
 class Sushiswap(BaseSwap):
-    def __init__(self, client: AClosableHTTPClient) -> None:
+    def __init__(
+        self,
+        client: AClosableHTTPClient,
+        url: str = "http://api.thegraph.com/subgraphs/name/sushiswap/exchange",
+    ) -> None:
         parser_dispatch = ParserDispatch(
             burn=parse_burn,
             liquidity_position=parse_liquidity_position,
             mint=parse_mint,
             swap=parse_swap,
         )
-        url = "https://api.thegraph.com/subgraphs/name/sushiswap/exchange"
-        # url = (
-        #    "https://api.thegraph.com/subgraphs/name/dimitarnestorov/sushiswap-subgraph"
-        # )
-
         BaseSwap.__init__(self, client, url, parser_dispatch)
-
-    async def __aenter__(self) -> "Sushiswap":
-        return self
