@@ -10,16 +10,15 @@ from thegraph_handlers.uniswap_v2.parsers import (
 
 
 class UniswapV2(BaseSwap):
-    def __init__(self, client: AClosableHTTPClient) -> None:
+    def __init__(
+        self,
+        client: AClosableHTTPClient,
+        url: str = "http://api.thegraph.com/subgraphs/name/uniswap/uniswap-v2",
+    ) -> None:
         parser_dispatch = ParserDispatch(
             burn=parse_burn,
             liquidity_position=parse_liquidity_position,
             mint=parse_mint,
             swap=parse_swap,
         )
-
-        url = "https://api.thegraph.com/subgraphs/name/uniswap/uniswap-v2"
         BaseSwap.__init__(self, client, url, parser_dispatch)
-
-    async def __aenter__(self) -> "UniswapV2":
-        return self
